# DistOptica (distoptica)

[![Test library](https://github.com/mrfitzpa/distoptica/actions/workflows/test_library.yml/badge.svg)](https://github.com/mrfitzpa/distoptica/actions/workflows/test_library.yml)
[![Code Coverage](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/mrfitzpa/e3d00c6ff78c39d52c8b3f1ca5da9065/raw/distoptica_coverage_badge.json)](https://github.com/mrfitzpa/distoptica/actions/workflows/measure_code_coverage.yml)
[![Documentation](https://img.shields.io/badge/docs-read-brightgreen)](https://mrfitzpa.github.io/distoptica)
[![PyPi Version](https://img.shields.io/pypi/v/distoptica.svg)](https://pypi.org/project/distoptica)
[![Conda-Forge Version](https://img.shields.io/conda/vn/conda-forge/distoptica.svg)](https://anaconda.org/conda-forge/distoptica)
[![License](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

`distoptica` is a Python library for modelling optical distortions.

Visit the `distoptica` [website](https://mrfitzpa.github.io/distoptica) for a web version
of the installation instructions, the reference guide, and the examples archive.

<!--
For those reading raw .rst files, see file `docs/INSTALL.rst` for instructions
on installing the `distoptica` library.
-->